@import "compass";
@import "forms";
@import "config";

body.login {
    background: $body-bkgnd;
}

.login {
    #container {
        background: white;
        width: 28em;
        margin: 100px auto 30px;
        border: 1px solid #D4D4D4;
        line-height: $base-line-height;
        min-width: 451px;
        min-height: 180px;
        height: auto;
        padding: 30px;
        position: relative;
        @include border-radius(8px);
        @include box-shadow(0px 1px 8px rgba(0,0,0,0.15));
        text-align: left;
    }
    #content {
        margin: 0;
        width: 230px;
        float: right;
    }
    #content-main {
        border-left: 1px solid #DDD;
        float: right;
        margin-left: 30px;
        min-height: 180px;
        padding-left: 30px;
        text-align: left;
        width: 230px;
    }
    #header {
        width: 160px;
        background: none;
        color: #333;
        -moz-box-shadow: none;
        -webkit-box-shadow: none;
        -o-box-shadow: none;
        box-shadow: none;
        display: inline-block;
    }
    #branding {
        vertical-align: middle;
        display: inline-block;
        float: left;
        height: 180px;
        margin: 0;
        padding: 0;
        min-width: 160px;
        background: none;
        width:160px;
        background: url(../img/logo.png) center center no-repeat;

    }
    #branding h1 {
        color: #333;
        padding: 0;
        margin: 0;
        text-indent: -999999px;
        vertical-align: middle;
        margin-top: auto;
    }

    .login #footer {
        padding: 0;
    }
    form {
        margin: 0;
    }

    .form-row {
        padding: 4px 0;
        float: left;
        width: 100%;
        margin: 0;
        border: 0;

        label {
            float: left;
            text-align: left;
            width: 9em;
            padding: 0;
            margin: 0;
            padding-right: 0.5em;
            line-height: 2em;
            font-size: 1em;
            color: #333;
            font-weight: bold;
        }

        input {
            width: 217px;
        }
    }

    span.help {
        font-size: 10px;
        display: block;
    }

    .submit-row {
        clear: both;
        padding: 10px 0 0 0;
        border: 0;
        margin: 0;
        background: transparent;
        @include box-shadow(none);
        @include border-radius(0);

        label {
            display: inline;
            width: 0;
            margin: 0;
        }
    }

    .password-reset-link {
        text-align: center;
    }
}

