@import "compass";

// Base class
@mixin well($padding: 19px, $borderradius: 4px) {
  min-height: 20px;
  padding: $padding;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid darken(#f5f5f5, 7%);
  @include border-radius($borderradius);
  @include box-shadow(inset 0 1px 1px rgba(0,0,0,.05));
  blockquote {
    border-color: #ddd;
    border-color: rgba(0,0,0,.15);
  }
}

.well {
  @include well;
}
// Sizes
.well-large {
  @include well(24px, 6px);
}
.well-small {
  @include well(9px, 3px);
}
