@import "compass";
@import "buttons";

.paginator {
    padding: 5px;
    .this-page {
        @include minibutton;
        @include buttonBackground(#fff, #fff, #333);
    }
    a {
        @include minibutton;
    }
    .showall {
        @include minibutton;
    }
    margin: 0;
    background-color: #f5f5f5;
    border: 1px solid #ddd;
    border-top: 0;
    color: #999;
    vertical-align: middle;
    font-size: 13px;
    @include border-bottom-radius(4px);
}