/* line 95, ../scss/sass/_buttons.scss */
button,
input[type="reset"],
input[type="button"],
input[type="submit"],
input[type="file"] > input[type="button"] {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
}
/* line 28, ../scss/sass/_buttons.scss */
button:hover,
input[type="reset"]:hover,
input[type="button"]:hover,
input[type="submit"]:hover,
input[type="file"] > input[type="button"]:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
button:focus,
input[type="reset"]:focus,
input[type="button"]:focus,
input[type="submit"]:focus,
input[type="file"] > input[type="button"]:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
button:active,
input[type="reset"]:active,
input[type="button"]:active,
input[type="submit"]:active,
input[type="file"] > input[type="button"]:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
button a,
input[type="reset"] a,
input[type="button"] a,
input[type="submit"] a,
input[type="file"] > input[type="button"] a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
button a:active, button a:focus,
input[type="reset"] a:active,
input[type="reset"] a:focus,
input[type="button"] a:active,
input[type="button"] a:focus,
input[type="submit"] a:active,
input[type="submit"] a:focus,
input[type="file"] > input[type="button"] a:active,
input[type="file"] > input[type="button"] a:focus {
  outline: none;
}
/* line 97, ../scss/sass/_buttons.scss */
button::-moz-focus-inner,
input[type="reset"]::-moz-focus-inner,
input[type="button"]::-moz-focus-inner,
input[type="submit"]::-moz-focus-inner,
input[type="file"] > input[type="button"]::-moz-focus-inner {
  border: none;
}

/* line 102, ../scss/sass/_buttons.scss */
input[type="submit"].default, button.default {
  color: white;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #499249;
  *background-color: #51a351;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #62c462), color-stop(100%, #51a351));
  background-image: -webkit-linear-gradient(#62c462, #51a351);
  background-image: -moz-linear-gradient(#62c462, #51a351);
  background-image: -o-linear-gradient(#62c462, #51a351);
  background-image: linear-gradient(#62c462, #51a351);
  border-color: #62c462 #62c462 #51a351;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
}
/* line 64, ../scss/sass/_buttons.scss */
input[type="submit"].default:hover, button.default:hover {
  color: white;
  background-color: #51a351;
  *background-color: #499249;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}

/* line 5, ../scss/sass/changelists.scss */
#changelist {
  position: relative;
  width: 100%;
  background: #eeeeee;
  border: 0;
}

/* line 12, ../scss/sass/changelists.scss */
#changelist.filtered {
  min-height: 400px;
}
/* line 14, ../scss/sass/changelists.scss */
#changelist.filtered .actions, #changelist.filtered .results, #changelist.filtered .xfull, #changelist.filtered .paginator, #changelist.filtered #toolbar {
  margin-right: 170px;
}

/* line 18, ../scss/sass/changelists.scss */
#changelist-filter {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1000;
  width: 160px;
  border: 1px solid #dddddd;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  background: white;
  margin: 0;
}
/* line 29, ../scss/sass/changelists.scss */
#changelist-filter h2 {
  background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #eeeef3), color-stop(100%, #d6dadf));
  background: -webkit-linear-gradient(#eeeef3, #d6dadf);
  background: -moz-linear-gradient(#eeeef3, #d6dadf);
  background: -o-linear-gradient(#eeeef3, #d6dadf);
  background: linear-gradient(#eeeef3, #d6dadf);
  -webkit-border-radius: 0 4px 0 0;
  -moz-border-radius: 0 4px 0 0;
  -ms-border-radius: 0 4px 0 0;
  -o-border-radius: 0 4px 0 0;
  border-radius: 0 4px 0 0;
  line-height: 1.2rem;
  border-bottom: 1px solid #dddddd;
}
/* line 35, ../scss/sass/changelists.scss */
#changelist-filter h3 {
  margin: 0;
  padding-bottom: 0;
  text-shadow: 0px 1px 1px rgba(255, 255, 255, 0.6);
}
/* line 40, ../scss/sass/changelists.scss */
#changelist-filter ul {
  list-style: none;
  font-size: .8rem;
  line-height: 1.3em;
  padding-left: 0;
}
/* line 11, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/lists/_bullets.scss */
#changelist-filter ul li {
  list-style-image: none;
  list-style-type: none;
  margin-left: 0;
}
/* line 45, ../scss/sass/changelists.scss */
#changelist-filter ul a {
  text-decoration: none;
  color: #333;
}
/* line 4, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_hover-link.scss */
#changelist-filter ul a:hover {
  text-decoration: underline;
}
/* line 49, ../scss/sass/changelists.scss */
#changelist-filter ul li {
  padding-left: 1em;
}
/* line 52, ../scss/sass/changelists.scss */
#changelist-filter ul li.selected {
  background-color: #e6e6e6;
}

/* line 58, ../scss/sass/changelists.scss */
#changelist-search {
  -moz-border-radius-topleft: 4px;
  -webkit-border-top-left-radius: 4px;
  border-top-left-radius: 4px;
  -moz-border-radius-topright: 4px;
  -webkit-border-top-right-radius: 4px;
  border-top-right-radius: 4px;
  line-height: 20px;
  border: 1px solid #dddddd;
  margin-bottom: 0;
  padding: 5px;
  background-color: whitesmoke;
}
/* line 65, ../scss/sass/changelists.scss */
#changelist-search label {
  font-size: 13px;
  width: auto;
  margin: 0;
  margin-left: .5em;
  padding: 0;
  float: none;
  display: inline;
  position: absolute;
  left: 6px;
}
/* line 75, ../scss/sass/changelists.scss */
#changelist-search label img {
  vertical-align: middle;
}
/* line 79, ../scss/sass/changelists.scss */
#changelist-search #searchbar {
  text-indent: 10px;
}
/* line 82, ../scss/sass/changelists.scss */
#changelist-search input[type=submit] {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
  margin-top: 0;
}
/* line 28, ../scss/sass/_buttons.scss */
#changelist-search input[type=submit]:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
#changelist-search input[type=submit]:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
#changelist-search input[type=submit]:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
#changelist-search input[type=submit] a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
#changelist-search input[type=submit] a:active, #changelist-search input[type=submit] a:focus {
  outline: none;
}

/* line 88, ../scss/sass/changelists.scss */
.results {
  border: 1px solid #dddddd;
  background: #fff;
}

/* line 92, ../scss/sass/changelists.scss */
#result_list {
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
}
/* line 94, ../scss/sass/changelists.scss */
#result_list th {
  width: auto;
}
/* line 97, ../scss/sass/changelists.scss */
#result_list th.action-checkbox-column, #result_list td.action-checkbox {
  width: 1.5em;
  text-align: center;
}
/* line 101, ../scss/sass/changelists.scss */
#result_list th.action-checkbox-column input, #result_list td.action-checkbox input {
  margin: 0;
}

/* line 107, ../scss/sass/changelists.scss */
.actions {
  vertical-align: middle;
  line-height: 20px;
  background-color: whitesmoke;
  padding: 5px;
  border-left: 1px solid #dddddd;
  border-right: 1px solid #dddddd;
  overflow: hidden;
  *zoom: 1;
}
/* line 114, ../scss/sass/changelists.scss */
.actions label {
  font-size: 13px;
  width: auto;
  margin: 0;
  margin-right: .5em;
  padding: 0;
  float: none;
  display: inline-block;
}
/* line 123, ../scss/sass/changelists.scss */
.actions label select {
  font-size: inherit;
  height: 20px;
}
/* line 128, ../scss/sass/changelists.scss */
.actions .action-counter, .actions .all {
  display: inline-block;
  color: #999;
  margin: 0 0.5em;
  vertical-align: middle;
  font-size: 13px;
  display: none;
}
/* line 136, ../scss/sass/changelists.scss */
.actions .button {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
  margin: 0;
}
/* line 28, ../scss/sass/_buttons.scss */
.actions .button:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.actions .button:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.actions .button:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.actions .button a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.actions .button a:active, .actions .button a:focus {
  outline: none;
}
/* line 140, ../scss/sass/changelists.scss */
.actions .clear, .actions .question {
  display: none;
}
/* line 143, ../scss/sass/changelists.scss */
.actions .clear a, .actions .question a {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
}
/* line 28, ../scss/sass/_buttons.scss */
.actions .clear a:hover, .actions .question a:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.actions .clear a:focus, .actions .question a:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.actions .clear a:active, .actions .question a:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.actions .clear a a, .actions .question a a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.actions .clear a a:active, .actions .clear a a:focus, .actions .question a a:active, .actions .question a a:focus {
  outline: none;
}

/* line 149, ../scss/sass/changelists.scss */
.xfull {
  vertical-align: middle;
  line-height: 20px;
  background-color: whitesmoke;
  padding: 5px;
  border-left: 1px solid #dddddd;
  border-right: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd;
}
/* line 157, ../scss/sass/changelists.scss */
.xfull .toplinks {
  padding-left: 0;
}
/* line 159, ../scss/sass/changelists.scss */
.xfull .toplinks li {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
}
/* line 28, ../scss/sass/_buttons.scss */
.xfull .toplinks li:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.xfull .toplinks li:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.xfull .toplinks li:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.xfull .toplinks li a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.xfull .toplinks li a:active, .xfull .toplinks li a:focus {
  outline: none;
}
/* line 163, ../scss/sass/changelists.scss */
.xfull br.clear {
  clear: both;
  display: none;
}
