/* line 1, ../scss/sass/changelist.scss */
#changelist-filter {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1000;
  width: 160px;
  border-left: 1px solid #ddd;
  background: #efefef;
  margin: 0;
}
