/* line 95, ../scss/sass/_buttons.scss */
button,
input[type="reset"],
input[type="button"],
input[type="submit"],
input[type="file"] > input[type="button"] {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
}
/* line 28, ../scss/sass/_buttons.scss */
button:hover,
input[type="reset"]:hover,
input[type="button"]:hover,
input[type="submit"]:hover,
input[type="file"] > input[type="button"]:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
button:focus,
input[type="reset"]:focus,
input[type="button"]:focus,
input[type="submit"]:focus,
input[type="file"] > input[type="button"]:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
button:active,
input[type="reset"]:active,
input[type="button"]:active,
input[type="submit"]:active,
input[type="file"] > input[type="button"]:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
button a,
input[type="reset"] a,
input[type="button"] a,
input[type="submit"] a,
input[type="file"] > input[type="button"] a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
button a:active, button a:focus,
input[type="reset"] a:active,
input[type="reset"] a:focus,
input[type="button"] a:active,
input[type="button"] a:focus,
input[type="submit"] a:active,
input[type="submit"] a:focus,
input[type="file"] > input[type="button"] a:active,
input[type="file"] > input[type="button"] a:focus {
  outline: none;
}
/* line 97, ../scss/sass/_buttons.scss */
button::-moz-focus-inner,
input[type="reset"]::-moz-focus-inner,
input[type="button"]::-moz-focus-inner,
input[type="submit"]::-moz-focus-inner,
input[type="file"] > input[type="button"]::-moz-focus-inner {
  border: none;
}

/* line 102, ../scss/sass/_buttons.scss */
input[type="submit"].default, button.default {
  color: white;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #499249;
  *background-color: #51a351;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #62c462), color-stop(100%, #51a351));
  background-image: -webkit-linear-gradient(#62c462, #51a351);
  background-image: -moz-linear-gradient(#62c462, #51a351);
  background-image: -o-linear-gradient(#62c462, #51a351);
  background-image: linear-gradient(#62c462, #51a351);
  border-color: #62c462 #62c462 #51a351;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
}
/* line 64, ../scss/sass/_buttons.scss */
input[type="submit"].default:hover, button.default:hover {
  color: white;
  background-color: #51a351;
  *background-color: #499249;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}

@font-face {
  font-family: "FontAwesome";
  src: url('../scss/../fonts/fontawesome-webfont.eot');
  src: url('../scss/../fonts/fontawesome-webfont.eot?#iefix') format('eot'), url('../scss/../fonts/fontawesome-webfont.woff') format('woff'), url('../scss/../fonts/fontawesome-webfont.ttf') format('truetype'), url('../scss/../fonts/fontawesome-webfont.svg#FontAwesomeRegular') format('svg');
  font-weight: normal;
  font-style: normal;
}

/* line 14, ../scss/sass/_icons.scss */
.fontawesome {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
}

/* line 57, ../scss/sass/_icons.scss */
.icon-2x {
  font-size: 2em;
}
/* line 59, ../scss/sass/_icons.scss */
.icon-2x.icon-border {
  border-width: 2px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
}

/* line 64, ../scss/sass/_icons.scss */
.icon-3x {
  font-size: 3em;
}
/* line 66, ../scss/sass/_icons.scss */
.icon-3x.icon-border {
  border-width: 3px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  -ms-border-radius: 5px;
  -o-border-radius: 5px;
  border-radius: 5px;
}

/* line 71, ../scss/sass/_icons.scss */
.icon-4x {
  font-size: 4em;
}
/* line 73, ../scss/sass/_icons.scss */
.icon-4x.icon-border {
  border-width: 4px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  -ms-border-radius: 6px;
  -o-border-radius: 6px;
  border-radius: 6px;
}

/* \f020 doesn't work in Safari. all shifted one down */
/* \f020 doesn't work in Safari. all shifted one down */
/* line 3, ../scss/sass/_breadcrumbs.scss */
.breadcrumbs {
  background: white;
  padding: 2px 8px 3px 8px;
  font-size: .8rem;
  color: #999;
  border-top: 1px solid white;
  border-bottom: 1px solid #cccccc;
  text-align: left;
  -webkit-box-shadow: rgba(0, 0, 0, 0.4) 0 0 5px;
  -moz-box-shadow: rgba(0, 0, 0, 0.4) 0 0 5px;
  box-shadow: rgba(0, 0, 0, 0.4) 0 0 5px;
}
/* line 13, ../scss/sass/_breadcrumbs.scss */
.breadcrumbs a:link, .breadcrumbs a:visited {
  color: #5B80B2;
  text-decoration: none;
}

/* SELECTOR (FILTER INTERFACE) */
/* line 5, ../scss/sass/_selectorwidget.scss */
.selector {
  overflow: hidden;
  *zoom: 1;
}
/* line 7, ../scss/sass/_selectorwidget.scss */
.selector select {
  width: 270px;
  height: 17.2em;
}
/* line 11, ../scss/sass/_selectorwidget.scss */
.selector .selector-filter {
  background: white;
  border: 1px solid #cccccc;
  border-width: 0 1px;
  padding: 3px;
  font-size: .625rem;
  margin: 0;
  text-align: left;
}
/* line 19, ../scss/sass/_selectorwidget.scss */
.selector .selector-filter label {
  width: 16px;
  padding: 2px;
  padding-top: 4px;
  margin: 0;
  margin-right: 5px;
}
/* line 27, ../scss/sass/_selectorwidget.scss */
.selector .selector-available input {
  width: 220px;
}
/* line 30, ../scss/sass/_selectorwidget.scss */
.selector ul.selector-chooser {
  float: left;
  height: 50px;
  margin: 10em 5px 0 5px;
  padding: 0;
}

/* line 38, ../scss/sass/_selectorwidget.scss */
.selector-available, .selector-chosen {
  float: left;
  width: 270px;
  text-align: center;
  margin-bottom: 5px;
}
/* line 44, ../scss/sass/_selectorwidget.scss */
.selector-available h2, .selector-chosen h2 {
  border: 1px solid #cccccc;
}

/* line 49, ../scss/sass/_selectorwidget.scss */
.selector-chosen select {
  border-top: none;
}

/* line 53, ../scss/sass/_selectorwidget.scss */
.selector-chooser li {
  margin: 0;
  padding: 3px;
  list-style-type: none;
}

/* line 59, ../scss/sass/_selectorwidget.scss */
.selector select {
  margin-bottom: 10px;
  margin-top: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  -o-border-radius: 0;
  border-radius: 0;
}

/* line 65, ../scss/sass/_selectorwidget.scss */
.selector-add, .selector-remove {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
}
/* line 28, ../scss/sass/_buttons.scss */
.selector-add:hover, .selector-remove:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.selector-add:focus, .selector-remove:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.selector-add:active, .selector-remove:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.selector-add a, .selector-remove a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.selector-add a:active, .selector-add a:focus, .selector-remove a:active, .selector-remove a:focus {
  outline: none;
}

/* line 35, ../scss/sass/_icons.scss */
.selector-add:after {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-left: .5em;
  content: "\f0da";
}

/* line 24, ../scss/sass/_icons.scss */
.selector-remove:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f0d9";
}

/* line 77, ../scss/sass/_selectorwidget.scss */
a.selector-chooseall, a.selector-clearall {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
}
/* line 28, ../scss/sass/_buttons.scss */
a.selector-chooseall:hover, a.selector-clearall:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
a.selector-chooseall:focus, a.selector-clearall:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
a.selector-chooseall:active, a.selector-clearall:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
a.selector-chooseall a, a.selector-clearall a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
a.selector-chooseall a:active, a.selector-chooseall a:focus, a.selector-clearall a:active, a.selector-clearall a:focus {
  outline: none;
}

/* line 35, ../scss/sass/_icons.scss */
a.selector-chooseall:after {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-left: .5em;
  content: "\f04e";
}

/* line 24, ../scss/sass/_icons.scss */
a.selector-clearall:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f04a";
}

/* STACKED SELECTORS */
/* line 92, ../scss/sass/_selectorwidget.scss */
.stacked {
  float: left;
  width: 485px;
}
/* line 35, ../scss/sass/_icons.scss */
.stacked .selector-add:after {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-left: .5em;
  content: "\f0d7";
}
/* line 24, ../scss/sass/_icons.scss */
.stacked .selector-remove:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f0d8";
}
/* line 103, ../scss/sass/_selectorwidget.scss */
.stacked select {
  width: 480px;
  height: 10.1em;
}
/* line 108, ../scss/sass/_selectorwidget.scss */
.stacked .selector-available, .stacked .selector-chosen {
  width: 480px;
}
/* line 112, ../scss/sass/_selectorwidget.scss */
.stacked .selector-available {
  margin-bottom: 0;
}
/* line 116, ../scss/sass/_selectorwidget.scss */
.stacked .selector-available input {
  width: 442px;
}
/* line 120, ../scss/sass/_selectorwidget.scss */
.stacked ul.selector-chooser {
  margin: 0 0 3px 40%;
  width: 480px;
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  *zoom: 1;
  padding-left: 160px;
}
/* line 60, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/lists/_horizontal-list.scss */
.stacked ul.selector-chooser li {
  list-style-image: none;
  list-style-type: none;
  margin-left: 0;
  white-space: nowrap;
  display: inline;
  float: left;
  padding-left: 4px;
  padding-right: 4px;
}
/* line 48, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/lists/_horizontal-list.scss */
.stacked ul.selector-chooser li:first-child, .stacked ul.selector-chooser li.first {
  padding-left: 0;
}
/* line 49, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/lists/_horizontal-list.scss */
.stacked ul.selector-chooser li:last-child {
  padding-right: 0;
}
/* line 50, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/lists/_horizontal-list.scss */
.stacked ul.selector-chooser li.last {
  padding-right: 0;
}
/* line 127, ../scss/sass/_selectorwidget.scss */
.stacked .selector-chooser li {
  float: left;
  padding: 3px 3px 3px 5px;
}
/* line 131, ../scss/sass/_selectorwidget.scss */
.stacked .selector-chooseall, .stacked .selector-clearall {
  display: none;
}

@font-face {
  font-family: "FontAwesome";
  src: url('../scss/../fonts/fontawesome-webfont.eot');
  src: url('../scss/../fonts/fontawesome-webfont.eot?#iefix') format('eot'), url('../scss/../fonts/fontawesome-webfont.woff') format('woff'), url('../scss/../fonts/fontawesome-webfont.ttf') format('truetype'), url('../scss/../fonts/fontawesome-webfont.svg#FontAwesomeRegular') format('svg');
  font-weight: normal;
  font-style: normal;
}

/* line 14, ../scss/sass/_icons.scss */
.fontawesome {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
}

/* line 57, ../scss/sass/_icons.scss */
.icon-2x {
  font-size: 2em;
}
/* line 59, ../scss/sass/_icons.scss */
.icon-2x.icon-border {
  border-width: 2px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
}

/* line 64, ../scss/sass/_icons.scss */
.icon-3x {
  font-size: 3em;
}
/* line 66, ../scss/sass/_icons.scss */
.icon-3x.icon-border {
  border-width: 3px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  -ms-border-radius: 5px;
  -o-border-radius: 5px;
  border-radius: 5px;
}

/* line 71, ../scss/sass/_icons.scss */
.icon-4x {
  font-size: 4em;
}
/* line 73, ../scss/sass/_icons.scss */
.icon-4x.icon-border {
  border-width: 4px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  -ms-border-radius: 6px;
  -o-border-radius: 6px;
  border-radius: 6px;
}

/* \f020 doesn't work in Safari. all shifted one down */
/* \f020 doesn't work in Safari. all shifted one down */
/* line 14, ../scss/sass/_messages.scss */
.messagelist {
  padding: 8px 35px 8px 14px;
  margin-bottom: 20px;
  color: #3a87ad;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
  border: 1px solid #fbeed5;
  background-color: #fcf8e3;
}
/* line 16, ../scss/sass/_messages.scss */
.messagelist li {
  line-height: 30px;
}
/* line 24, ../scss/sass/_icons.scss */
.messagelist .debug:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f085";
}
/* line 24, ../scss/sass/_icons.scss */
.messagelist .info:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f05a";
}
/* line 25, ../scss/sass/_messages.scss */
.messagelist .success {
  color: #468847;
}
/* line 24, ../scss/sass/_icons.scss */
.messagelist .success:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f058";
}
/* line 29, ../scss/sass/_messages.scss */
.messagelist .warning {
  color: #c09853;
}
/* line 24, ../scss/sass/_icons.scss */
.messagelist .warning:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f071";
}
/* line 33, ../scss/sass/_messages.scss */
.messagelist .error {
  color: #b94a48;
}
/* line 24, ../scss/sass/_icons.scss */
.messagelist .error:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f05e";
}

/* line 4, ../scss/sass/_tables.scss */
table {
  border-spacing: 0;
}
/* line 6, ../scss/sass/_tables.scss */
table th, table td {
  line-height: 20px;
  text-align: left;
  border-top: 1px solid 1px solid #dddddd;
  border-left: 1px solid 1px solid #dddddd;
  padding: 5px;
}
/* line 13, ../scss/sass/_tables.scss */
table th {
  font-weight: bold;
  padding: 2px 5px;
}
/* line 18, ../scss/sass/_tables.scss */
table tr th:first-child, table tr td:first-child {
  border-left: 0;
}
/* line 23, ../scss/sass/_tables.scss */
table thead th {
  border-top: 0;
  background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background: -moz-linear-gradient(#ffffff, #e6e6e6);
  background: -o-linear-gradient(#ffffff, #e6e6e6);
  background: linear-gradient(#ffffff, #e6e6e6);
  font-size: .8rem;
}
/* line 27, ../scss/sass/_tables.scss */
table thead th .text a {
  display: block;
  cursor: pointer;
  padding: 2px 5px;
}
/* line 32, ../scss/sass/_tables.scss */
table thead th:hover {
  background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #e6e6e6), color-stop(100%, #d9d9d9));
  background: -webkit-linear-gradient(#e6e6e6, #d9d9d9);
  background: -moz-linear-gradient(#e6e6e6, #d9d9d9);
  background: -o-linear-gradient(#e6e6e6, #d9d9d9);
  background: linear-gradient(#e6e6e6, #d9d9d9);
}
/* line 24, ../scss/sass/_icons.scss */
table thead th:hover .sortremove:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f057";
}
/* line 39, ../scss/sass/_tables.scss */
table thead th.sorted .sortoptions {
  display: block;
  float: right;
  text-align: right;
}
/* line 43, ../scss/sass/_tables.scss */
table thead th.sorted .sortoptions a {
  display: inline-block;
  width: 14px;
  height: 1.1em;
}
/* line 51, ../scss/sass/_tables.scss */
table tbody th, table tbody td {
  border-top: 1px solid 1px solid #dddddd;
  background: transparent;
}
/* line 56, ../scss/sass/_tables.scss */
table tbody tr.row2 {
  background: #f9f9f9;
}
/* line 59, ../scss/sass/_tables.scss */
table tbody tr:hover, table tbody tr.row2:hover {
  background: whitesmoke;
}

/* line 24, ../scss/sass/_icons.scss */
.sortoptions .ascending:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f0de";
}
/* line 24, ../scss/sass/_icons.scss */
.sortoptions .descending:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f0dd";
}

/* line 95, ../scss/sass/_buttons.scss */
button,
input[type="reset"],
input[type="button"],
input[type="submit"],
input[type="file"] > input[type="button"] {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
}
/* line 28, ../scss/sass/_buttons.scss */
button:hover,
input[type="reset"]:hover,
input[type="button"]:hover,
input[type="submit"]:hover,
input[type="file"] > input[type="button"]:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
button:focus,
input[type="reset"]:focus,
input[type="button"]:focus,
input[type="submit"]:focus,
input[type="file"] > input[type="button"]:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
button:active,
input[type="reset"]:active,
input[type="button"]:active,
input[type="submit"]:active,
input[type="file"] > input[type="button"]:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
button a,
input[type="reset"] a,
input[type="button"] a,
input[type="submit"] a,
input[type="file"] > input[type="button"] a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
button a:active, button a:focus,
input[type="reset"] a:active,
input[type="reset"] a:focus,
input[type="button"] a:active,
input[type="button"] a:focus,
input[type="submit"] a:active,
input[type="submit"] a:focus,
input[type="file"] > input[type="button"] a:active,
input[type="file"] > input[type="button"] a:focus {
  outline: none;
}
/* line 97, ../scss/sass/_buttons.scss */
button::-moz-focus-inner,
input[type="reset"]::-moz-focus-inner,
input[type="button"]::-moz-focus-inner,
input[type="submit"]::-moz-focus-inner,
input[type="file"] > input[type="button"]::-moz-focus-inner {
  border: none;
}

/* line 102, ../scss/sass/_buttons.scss */
input[type="submit"].default, button.default {
  color: white;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #499249;
  *background-color: #51a351;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #62c462), color-stop(100%, #51a351));
  background-image: -webkit-linear-gradient(#62c462, #51a351);
  background-image: -moz-linear-gradient(#62c462, #51a351);
  background-image: -o-linear-gradient(#62c462, #51a351);
  background-image: linear-gradient(#62c462, #51a351);
  border-color: #62c462 #62c462 #51a351;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
}
/* line 64, ../scss/sass/_buttons.scss */
input[type="submit"].default:hover, button.default:hover {
  color: white;
  background-color: #51a351;
  *background-color: #499249;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}

/* line 4, ../scss/sass/_pagination.scss */
.paginator {
  padding: 5px;
  margin: 0;
  background-color: #f5f5f5;
  border: 1px solid #dddddd;
  border-top: 0;
  color: #999;
  vertical-align: middle;
  font-size: 13px;
  -moz-border-radius-bottomleft: 4px;
  -webkit-border-bottom-left-radius: 4px;
  border-bottom-left-radius: 4px;
  -moz-border-radius-bottomright: 4px;
  -webkit-border-bottom-right-radius: 4px;
  border-bottom-right-radius: 4px;
}
/* line 6, ../scss/sass/_pagination.scss */
.paginator .this-page {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
  color: #333333;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #f2f2f2;
  *background-color: white;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #ffffff));
  background-image: -webkit-linear-gradient(#ffffff, #ffffff);
  background-image: -moz-linear-gradient(#ffffff, #ffffff);
  background-image: -o-linear-gradient(#ffffff, #ffffff);
  background-image: linear-gradient(#ffffff, #ffffff);
  border-color: white white white;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
}
/* line 28, ../scss/sass/_buttons.scss */
.paginator .this-page:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.paginator .this-page:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.paginator .this-page:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.paginator .this-page a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.paginator .this-page a:active, .paginator .this-page a:focus {
  outline: none;
}
/* line 64, ../scss/sass/_buttons.scss */
.paginator .this-page:hover {
  color: #333333;
  background-color: white;
  *background-color: #f2f2f2;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 10, ../scss/sass/_pagination.scss */
.paginator a {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
}
/* line 28, ../scss/sass/_buttons.scss */
.paginator a:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.paginator a:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.paginator a:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.paginator a a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.paginator a a:active, .paginator a a:focus {
  outline: none;
}
/* line 13, ../scss/sass/_pagination.scss */
.paginator .showall {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
}
/* line 28, ../scss/sass/_buttons.scss */
.paginator .showall:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.paginator .showall:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.paginator .showall:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.paginator .showall a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.paginator .showall a:active, .paginator .showall a:focus {
  outline: none;
}

/* line 12, ../scss/sass/base.scss */
ul {
  margin: 0;
}

/* line 16, ../scss/sass/base.scss */
body {
  background: #eeeeee;
  color: #333333;
  font-family: "Helvetica Neue", Arial, Helvetica, sans-serif;
  font-size: 16px;
  line-height: 20px;
  margin: 0;
}

/* line 25, ../scss/sass/base.scss */
h1 {
  font-size: 1.3rem;
  padding: 0 0.4rem 0 0;
  margin: 0 0 0.2rem 0;
  font-weight: bold;
  line-height: 2.2rem;
}

/* line 33, ../scss/sass/base.scss */
#header {
  background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #6c7a95), color-stop(100%, #4d5b76));
  background: -webkit-linear-gradient(#6c7a95, #4d5b76);
  background: -moz-linear-gradient(#6c7a95, #4d5b76);
  background: -o-linear-gradient(#6c7a95, #4d5b76);
  background: linear-gradient(#6c7a95, #4d5b76);
  -webkit-box-shadow: rgba(0, 0, 0, 0.4) 0 0 5px;
  -moz-box-shadow: rgba(0, 0, 0, 0.4) 0 0 5px;
  box-shadow: rgba(0, 0, 0, 0.4) 0 0 5px;
  color: #fff;
  overflow: hidden;
  width: 100%;
}
/* line 40, ../scss/sass/base.scss */
#header h1 {
  padding: 0 10px;
  font-size: 1.1rem;
  margin: 8px 0;
  font-weight: normal;
  line-height: 20px;
}

/* line 49, ../scss/sass/base.scss */
#user-tools {
  position: absolute;
  top: 0;
  right: 0;
  padding: 0.5rem 10px;
  font-size: .8rem;
  text-align: right;
}
/* line 57, ../scss/sass/base.scss */
#user-tools a {
  text-decoration: none;
  color: white;
}
/* line 4, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_hover-link.scss */
#user-tools a:hover {
  text-decoration: underline;
}

/* line 63, ../scss/sass/base.scss */
.add-another {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 0 6px;
  margin-left: .5em;
}
/* line 28, ../scss/sass/_buttons.scss */
.add-another:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.add-another:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.add-another:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.add-another a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.add-another a:active, .add-another a:focus {
  outline: none;
}
/* line 24, ../scss/sass/_icons.scss */
.add-another:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f067";
}
/* line 66, ../scss/sass/base.scss */
.add-another:before {
  margin-right: 0;
}
/* line 69, ../scss/sass/base.scss */
.add-another img {
  display: none;
}

/* line 75, ../scss/sass/base.scss */
#content {
  margin: 10px 15px;
}

/* line 79, ../scss/sass/base.scss */
#content.colMS {
  margin-right: 20em;
}

/* A module is a box used in a variety of ways in the admin:
    Dashboard:
        Apps: Each app is a module containing a table
        Recent Actions: Module with an h2, h3 and a p or a ul;
*/
/* line 103, ../scss/sass/base.scss */
.module {
  margin-bottom: .3rem;
  background: white;
  border: 1px solid #d4d4d4;
  line-height: 1.63rem;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
}
/* line 111, ../scss/sass/base.scss */
.module table {
  width: 100%;
  font-size: .9em;
}
/* line 114, ../scss/sass/base.scss */
.module table th {
  font-weight: bold;
  width: 100%;
}
/* line 117, ../scss/sass/base.scss */
.module table th a {
  color: #5b80b2;
  text-decoration: none;
}
/* line 18, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_link-colors.scss */
.module table th a:visited {
  color: #5b80b2;
}
/* line 21, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_link-colors.scss */
.module table th a:focus {
  color: #5b80b2;
}
/* line 24, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_link-colors.scss */
.module table th a:hover {
  color: #4d6c97;
}
/* line 27, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_link-colors.scss */
.module table th a:active {
  color: #7393bd;
}
/* line 123, ../scss/sass/base.scss */
.module caption, .module h2 {
  margin: 0;
  padding: 2px 5px 3px 5px;
  font-size: .9rem;
  text-align: left;
  font-weight: bold;
  -webkit-border-radius: 8px 8px 0 0;
  -moz-border-radius: 8px 8px 0 0;
  -ms-border-radius: 8px 8px 0 0;
  -o-border-radius: 8px 8px 0 0;
  border-radius: 8px 8px 0 0;
  background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #efefef));
  background: -webkit-linear-gradient(#ffffff, #efefef);
  background: -moz-linear-gradient(#ffffff, #efefef);
  background: -o-linear-gradient(#ffffff, #efefef);
  background: linear-gradient(#ffffff, #efefef);
  border-bottom: 1px solid #c8c8cb;
}
/* line 98, ../scss/sass/base.scss */
.module caption a, .module h2 a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.module caption a:active, .module caption a:focus, .module h2 a:active, .module h2 a:focus {
  outline: none;
}
/* line 126, ../scss/sass/base.scss */
.module h3 {
  font-size: .8rem;
  font-weight: bold;
  padding: 5px;
  margin-top: 1em;
  margin-bottom: 0;
}

/* line 135, ../scss/sass/base.scss */
.object-tools {
  padding-left: 0;
  padding-top: 0;
  float: right;
  position: relative;
  margin-top: -2.1em;
  margin-bottom: -2em;
}
/* line 143, ../scss/sass/base.scss */
.object-tools li {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  text-decoration: none;
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #e6e6e6);
  background-image: -moz-linear-gradient(#ffffff, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #e6e6e6);
  background-image: linear-gradient(#ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #bbbbbb;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #a2a2a2;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  -o-border-radius: 0;
  border-radius: 0;
  float: left;
}
/* line 28, ../scss/sass/_buttons.scss */
.object-tools li:hover {
  color: #333333;
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition-property: background-position;
  -moz-transition-property: background-position;
  -o-transition-property: background-position;
  transition-property: background-position;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  -o-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
/* line 38, ../scss/sass/_buttons.scss */
.object-tools li:focus {
  outline: thin dotted #333333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 44, ../scss/sass/_buttons.scss */
.object-tools li:active {
  position: relative;
  top: 1px;
}
/* line 50, ../scss/sass/_buttons.scss */
.object-tools li a {
  color: inherit;
  text-decoration: inherit;
  cursor: inherit;
}
/* line 6, ../../../../../../../../Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/typography/links/_unstyled-link.scss */
.object-tools li a:active, .object-tools li a:focus {
  outline: none;
}
/* line 148, ../scss/sass/base.scss */
.object-tools li + li {
  margin-left: -1px;
}
/* line 151, ../scss/sass/base.scss */
.object-tools li:first-child {
  margin-left: 0;
  -moz-border-radius-topleft: 4px;
  -webkit-border-top-left-radius: 4px;
  border-top-left-radius: 4px;
  -moz-border-radius-bottomleft: 4px;
  -webkit-border-bottom-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
/* line 155, ../scss/sass/base.scss */
.object-tools li:last-child {
  margin-right: 0;
  -moz-border-radius-topright: 4px;
  -webkit-border-top-right-radius: 4px;
  border-top-right-radius: 4px;
  -moz-border-radius-bottomright: 4px;
  -webkit-border-bottom-right-radius: 4px;
  border-bottom-right-radius: 4px;
}
/* line 35, ../scss/sass/_icons.scss */
.object-tools .viewsitelink:after {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-left: .5em;
  content: "\f061";
}
/* line 24, ../scss/sass/_icons.scss */
.object-tools .addlink:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  line-height: .9em;
  margin-right: .5em;
  content: "\f067";
}

/* line 169, ../scss/sass/base.scss */
#change-history tbody th {
  width: 18em;
}
/* line 172, ../scss/sass/base.scss */
#change-history thead th {
  width: auto;
}
